@@ -4,14 +4,14 @@ use warnings;
 use Exporter 'import';
 our @EXPORT_OK = qw(fa2hs);
 
-our $VERSION = '0.1.2'; # VERSION: 
+our $VERSION = '0.1.3'; # VERSION: 
 # ABSTRACT: get one or more sequences from a FASTA file quickly.
 
 
 sub new {
   my $class = shift;
-  my $self =  ref $_[0] ? %{ $_[0] } : @_;
-  $self->{file} || die `pod2text $0`;
+  my $self =  ref $_[0] ? $_[0] : {@_};
+  $self->{file} || die `file parameter is not exist`;
   bless $self, $class;
 }
 
@@ -82,7 +82,7 @@ Bio::SeqHash - get one or more sequences from a FASTA file quickly.
 
 =head1 VERSION
 
-version 0.1.2
+version 0.1.3
 
 =head1 SYNOPSIS
 
